==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Összes betűtípus</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Rendszer</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Felhasználó</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Kedvencek</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktív</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Kínai</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Egyoldalas</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Sérült fájl</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Ugyanaz a verzió már telepítve</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Rendszer betűtípus</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Betűtípusok</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 betűtípus telepítve</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 betűtípusok telepítve</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>Valóban törölni szeretné ezt a betűtípust?</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Ez a betűtípus nem lesz elérhető az alkalmazások számára</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Ezek a betűtípusok nem lesznek elérhetőek az alkalmazások számára</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>A többi %1 rendszer betűtípusok nem törölhetőek</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>A használatban lévő &quot;%1&quot; betűtípus nem törölhető</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>A többi %1 rendszer betűtípusok és a használatban lévő &quot;%2&quot; betűtípus nem törölhető</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Biztosan törölni szeretné a %1 betűtípus(oka)t?</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Betűtípusok törlése, kérjük várjon...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Betűtípus ellenőrzése</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Folytatás</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Nincs telepítendő betűtípus</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Ne hagyd, hogy az álmaid csak álmok legyenek</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Alapvető információk</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stílus</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verzió</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Teljes név</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Rövidített név</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Védjegy</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Betűkészlet kezelő</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>A Betűkészlet kezelő segít a felhasználóknak a betűtípusok telepítésében és kezelésében.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Betűtípusok betöltése, kérjük várjon...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>A betűtípus az asztalra exportálva</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 betűtípus az asztalra exportálva</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Nem sikerült exportálni 1 betűtípust. Nincs elég lemezterület.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Nem sikerült exportálni a %1 betűtípust. Nincs elég lemezterület.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Betűtípus hozzáadása</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Engedélyezés</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Tiltás</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eltávolítás a kedvencekből</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Részletek</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Megjelenítés a fájlkezelőben</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportálás</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>felfüggesztve</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>A betűtípusok felfüggesztésre kerültek</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>A %1 használatban van, ezért nem tilthatja le</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Nem tilthatja le a rendszer betűtípusait és a használt betűtípusokat</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Nem tilthatja le a rendszer betűtípusait</translation>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation>Egyes betűtípusok nem tilthatók le</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Betűtípus telepítése</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Ellenőrzés...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Sérült fájl</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Telepítve</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Nincs telepítve</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Betűtípus telepítése</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Nincs keresési eredmény</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Nincsenek betűtípusok</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Segítség</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Parancsikonok megjelenítése</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Oldal tetejére</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Oldal aljára</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Betűtípus hozzáadása</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eltávolítás a kedvencekből</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Betűtípus információ</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Szövegbevitel előnézete</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Sérült fájl</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Összes betűtípus</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Rendszer</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Felhasználó</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Kedvencek</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktív</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Kínai</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Egyoldalas</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>A %1 egy betűtípus család, ha folytatja, akkor a benne lévő összes betűtípus törlésre kerül</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>A %1 egy betűtípus család, ha folytatja, akkor az összes betűtípus engedélyezve lesz</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>A %1 egy betűtípus család, ha folytatja, akkor az összes betűtípus le lesz tiltva</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Engedélyezés</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Tiltás</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Az összes kiválasztott betűtípus család alkalmazása</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Sérült fájl</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Ugyanaz a verzió már telepítve</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Rendszer betűtípus</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>A %1 betűtípus telepítve</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>A %1 betűtípusok telepítve</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>A %1 betűtípus telepítése sikertelen. Nincs elég lemezterület.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>A %1 betűtípusok telepítése sikertelen. Nincs elég lemezterület.</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Ez a betűtípus nem lesz elérhető az alkalmazások számára</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Ezek a betűtípusok nem lesznek elérhetőek az alkalmazások számára</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>A többi %1 rendszer betűtípusok nem törölhetőek</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>A használatban lévő &quot;%1&quot; betűtípus nem törölhető</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>A többi %1 rendszer betűtípusok és a használatban lévő &quot;%2&quot; betűtípus nem törölhető</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Biztosan törölni szeretné a %1 betűtípus(oka)t?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Törlés</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Betűtípusok törlése, kérjük várjon...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Betűtípus ellenőrzése</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Nincs telepítendő betűtípus</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Kilépés</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Folytatás</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Alapvető információk</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stílus</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verzió</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Teljes név</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Rövidített név</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Védjegy</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Betűkészlet kezelő</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>A Betűkészlet Kezelő segít a felhasználóknak a betűtípusok telepítésében és kezelésében.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Betűtípusok betöltése, kérjük várjon...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>A betűtípus az asztalra exportálva</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 betűtípus az asztalra exportálva</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Nem sikerült exportálni 1 betűtípust. Nincs elég lemezterület.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Nem sikerült exportálni a %1 betűtípust. Nincs elég lemezterület.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Betűtípus hozzáadása</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Engedélyezés</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Tiltás</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eltávolítás a kedvencekből</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Részletek</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Megjelenítés a fájlkezelőben</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportálás</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>Felfüggesztve</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>A betűtípusok felfüggesztésre kerültek</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>A %1 használatban van, ezért nem tilthatja le</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Nem tilthatja le a rendszer betűtípusait és a használt betűtípusokat</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Nem tilthatja le a rendszer betűtípusait</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Betűtípus telepítése</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Ellenőrzés...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Sérült fájl</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Telepítve</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Nincs telepítve</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Betűtípus telepítése</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Nincs keresési eredmény</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Nincsenek betűtípusok</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Segítség</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Parancsikonok megjelenítése</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Oldal tetejére</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Oldal aljára</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Betűtípus hozzáadása</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kedvenc</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eltávolítás a kedvencekből</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Betűtípus információ</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Szövegbevitel előnézete</translation>
    </message>
</context>
</TS>
